==> phpaga-0.3.tar.bz2: phpaga-0.3/htdocs/bmt_plugins.php <==
<?php
/**
 * phpaga
 *
 * Billing method plugins
 *
 * This is the billing method plugins management interface.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: bmt_plugins.php 726 2006-08-05 22:34:30Z florian $
 *
 * Copyright (c) 2004, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$bmtlist = array();

phpaga_header(array("menuitem" => "administration"));

if (isset($_REQUEST["action"]))
{
    switch ($_REQUEST["action"])
    {
        case ACTION_DELETE:
            if (isset($_REQUEST["id"]) && is_numeric($_REQUEST["id"]))
            {
                $result = phpaga_bills_delete_bmt_plugin($_REQUEST["id"]);
                if ($result != PHPAGA_ERR_NONE)
                    phpaga_error($result);

            }
            break;

        case ACTION_ENABLE:
        case ACTION_DISABLE:

            if ($_REQUEST["action"] == ACTION_DISABLE)
                $status = 10;
            else
                $status = null;

            if (isset($_REQUEST["id"]) && is_numeric($_REQUEST["id"]))
            {
                $result = phpaga_bills_setPluginStatus($_REQUEST["id"], $status);
                if ($result != PHPAGA_ERR_NONE)
                    phpaga_error($result);

            }
            break;

        default:
            break;
    }
}

$result = phpaga_bills_getPluginList($bmtlist);
if ($result != PHPAGA_ERR_NONE)
{
    phpaga_error($result);
}

$tpl = new psmarty;
$tpl->assign("bmtlist", $bmtlist);
$tpl->display("bmt_plugins.tpl.html");

phpaga_footer();

?>

==> phpaga-0.6.tar.bz2: phpaga-0.6/htdocs/bmt_plugins.php <==
<?php
/**
 * phpaga
 *
 * Billing method plugins
 *
 * This is the billing method plugins management interface.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2004, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once('./config.php');
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$bmtlist = array();

phpaga_header(array('menuitem' => 'administration'));

if (isset($REQUEST_DATA['action'])) {

    switch ($REQUEST_DATA['action']) {

        case ACTION_DELETE:
            if (isset($REQUEST_DATA['id']) && is_numeric($REQUEST_DATA['id'])) {

                $result = phpaga_bills_delete_bmt_plugin($REQUEST_DATA['id']);

                if (PhPagaError::isError($result))
                    $result->printMessage();
            }
            break;

        case ACTION_ENABLE:
        case ACTION_DISABLE:

            if ($REQUEST_DATA['action'] == ACTION_DISABLE)
                $status = 10;
            else
                $status = null;

            if (isset($REQUEST_DATA['id']) && is_numeric($REQUEST_DATA['id'])) {

                $result = phpaga_bills_setPluginStatus($REQUEST_DATA['id'], $status);

                if (PhPagaError::isError($result))
                    $result->printMessage();
            }
            break;

        default:
            break;
    }
}

$bmtlist = phpaga_bills_getPluginList();

if (PhPagaError::isError($bmtlist))
    $bmtlist->printMessage();

$tpl = new psmarty;
$tpl->assign('bmtlist', $bmtlist);
$tpl->display('bmt_plugins.tpl.html');

phpaga_footer();

?>
